/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.shared.renderkit;

import javax.faces.component.UIComponent;
import javax.faces.component.UISelectMany;
import javax.faces.context.FacesContext;
import javax.faces.convert.Converter;
import javax.faces.convert.ConverterException;

import junit.framework.TestCase;

import org.apache.shale.test.mock.MockFacesContext;

/**
 * @author Mathias Broekelmann (latest modification by $Author: mbr $)
 * @version $Revision: 500553 $ $Date: 2007-01-27 10:50:39 -0500 (Sat, 27 Jan 2007) $
 */
public class RendererUtilsTest extends TestCase
{
    /**
     * test for MYFACES-731
     * A converter getAsString method should not be called for submitted values 
     * @throws Exception
     */
    public void testGetSubmittedValuesAsSet() throws Exception
    {
        MockFacesContext ctx = new MockFacesContext();
        UISelectMany cmp = new UISelectMany();
        cmp.setSubmittedValue(new String[] {"testValue"});
        Converter testConverter = new Converter()
        {
            public Object getAsObject(FacesContext context,
                    UIComponent component, String value)
                    throws ConverterException
            {
                fail("getAsObject should not get called");
                throw new UnsupportedOperationException();
            }

            public String getAsString(FacesContext context,
                    UIComponent component, Object value)
                    throws ConverterException
            {
                fail("getAsString should not get called");
                throw new UnsupportedOperationException();
            }
        };
        RendererUtils.getSubmittedValuesAsSet(ctx, cmp, testConverter, cmp);
    }
}
