/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.shared.renderkit.html;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import junit.framework.Test;
import junit.framework.TestSuite;

import org.apache.shale.test.base.AbstractJsfTestCase;

/**
 * @author cagatay (latest modification by $Author: skitching $)
 * @version $Revision: 673826 $ $Date: 2008-07-03 16:43:52 -0500 (Thu, 03 Jul 2008) $
 */
public class HtmlRendererUtilsTest extends AbstractJsfTestCase {

    public HtmlRendererUtilsTest(String name) {
        super(name);
    }

    public void setUp() {
        super.setUp();
    }

    public void tearDown() {
        super.tearDown();
    }

    public static Test suite() {
        return new TestSuite(HtmlRendererUtilsTest.class);
    }

    public void testSelectContentType() {
        MockExternalContext mockExternalContext = new MockExternalContext(servletContext,request, response);
        facesContext.setExternalContext(mockExternalContext);
        
        mockExternalContext.getRequestHeaderMap().put("Accept", "text/html");
        String selectedContentType = HtmlRendererUtils.selectContentType(null);
        assertEquals("text/html", selectedContentType);
        
        mockExternalContext.getRequestHeaderMap().put("Accept", "text/*");
        selectedContentType = HtmlRendererUtils.selectContentType(null);
        assertEquals("text/html", selectedContentType);
        
        mockExternalContext.getRequestHeaderMap().put("Accept", "text/xml");
        selectedContentType = HtmlRendererUtils.selectContentType(null);
        assertEquals("application/xhtml+xml", selectedContentType);
    }

    //shale's external context does not support playing with request header map
    static public class MockExternalContext extends org.apache.shale.test.mock.MockExternalContext {

        private Map requestHeaderMap = new HashMap();

        public MockExternalContext(ServletContext context,HttpServletRequest request, HttpServletResponse response) {
            super(context, request, response);
        }

        public Map getRequestHeaderMap() {
            return requestHeaderMap;
        }

        public void setRequestHeaderMap(Map requestHeaderMap) {
            this.requestHeaderMap = requestHeaderMap;
        }
    }
}