/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.shared.util;

import java.util.Locale;
import java.util.ResourceBundle;

import javax.faces.application.FacesMessage;

import junit.framework.Test;
import junit.framework.TestSuite;

import org.apache.shale.test.base.AbstractJsfTestCase;

/**
 * TestCase for MessageUtils
 *
 * @author Stephan Strittmatter
 */
public class MessageUtilsTest extends AbstractJsfTestCase
{

    private static final String DEFAULT_BUNDLE = "javax.faces.Messages";
    
    public MessageUtilsTest(String name)
    {
        super(name);
    }

    public static Test suite() {
        return new TestSuite(MessageUtilsTest.class); // keep this method or maven won't run it
    }

    public void setUp()
    {
        // TODO Auto-generated method stub
        super.setUp();
    }

    public void tearDown()
    {
        // TODO Auto-generated method stub
        super.tearDown();
    }

    /**
     * Test method for 'org.apache.myfaces.shared.util.MessageUtils.getMessage(Severity, String, Object)'
     */
    public void testGetMessageSeverityStringObject() throws Exception
    {
        facesContext.getViewRoot().setLocale(Locale.ENGLISH);

        FacesMessage msg = MessageUtils.getMessage(FacesMessage.SEVERITY_ERROR,
                "javax.faces.component.UIInput.CONVERSION", null);
        assertEquals("Conversion Error", msg.getSummary());

        facesContext.getViewRoot().setLocale(Locale.GERMAN);
        
        msg = MessageUtils.getMessage(FacesMessage.SEVERITY_ERROR,
                "javax.faces.component.UIInput.CONVERSION",
                "blubb");
        assertEquals("Konvertierungsfehler", msg.getSummary());
    }

    /**
     * Test method for 'org.apache.myfaces.shared.util.MessageUtils.getMessage(Severity, String, Object[])'
     */
    public void testGetMessageSeverityStringObjectArray() throws Exception
    {
        facesContext.getViewRoot().setLocale(Locale.ENGLISH);
        
        FacesMessage msg = MessageUtils.getMessage(FacesMessage.SEVERITY_ERROR,
                "javax.faces.component.UIInput.CONVERSION", null);
        assertEquals("Conversion Error", msg.getSummary());

        facesContext.getViewRoot().setLocale(Locale.GERMAN);
        
        msg = MessageUtils.getMessage(FacesMessage.SEVERITY_ERROR,
                "javax.faces.component.UIInput.CONVERSION", null);
        assertEquals("Konvertierungsfehler", msg.getSummary());
    }

    /**
     * Test method for 'org.apache.myfaces.shared.util.MessageUtils.getMessage(Severity, String, Object[], FacesContext)'
     */
    public void testGetMessageSeverityStringObjectArrayFacesContext() throws Exception
    {
        facesContext.getViewRoot().setLocale(Locale.ENGLISH);
        
        FacesMessage msg = MessageUtils.getMessage(FacesMessage.SEVERITY_ERROR,
                "javax.faces.component.UIInput.CONVERSION", null, facesContext);
        assertEquals("Conversion Error", msg.getSummary());

        facesContext.getViewRoot().setLocale(Locale.GERMAN);
        
        msg = MessageUtils.getMessage(FacesMessage.SEVERITY_ERROR,
                "javax.faces.component.UIInput.CONVERSION", null,
                facesContext);
        assertEquals("Konvertierungsfehler", msg.getSummary());
    }

    /**
     * Test method for 'org.apache.myfaces.shared.util.MessageUtils.getMessage(Locale, String, Object[])'
     */
    public void testGetMessageLocaleStringObjectArray() throws Exception
    {
        facesContext.getViewRoot().setLocale(Locale.ENGLISH);
        
        FacesMessage msg = org.apache.myfaces.shared.util.MessageUtils.getMessage(Locale.ENGLISH,
                "javax.faces.component.UIInput.CONVERSION", null);
        assertEquals("Conversion Error", msg.getSummary());

        msg = MessageUtils.getMessage(Locale.GERMAN,
                "javax.faces.component.UIInput.CONVERSION", null);
        assertEquals("Konvertierungsfehler", msg.getSummary());

    }

    /**
     * Test method for 'org.apache.myfaces.shared.util.MessageUtils.getMessage(FacesContext, String)'
     */
    public void testGetMessageFacesContextString() throws Exception
    {
        facesContext.getViewRoot().setLocale(Locale.ENGLISH);
        
        FacesMessage msg = MessageUtils.getMessage(facesContext,
                "javax.faces.component.UIInput.CONVERSION");
        assertEquals("Conversion Error", msg.getSummary());

        facesContext.getViewRoot().setLocale(Locale.GERMAN);
        
        msg = MessageUtils.getMessage(facesContext,
                "javax.faces.component.UIInput.CONVERSION");
        assertEquals("Konvertierungsfehler", msg.getSummary());
    }

    /**
     * Test method for 'org.apache.myfaces.shared.util.MessageUtils.getMessage(FacesContext, String, Object[])'
     */
    public void testGetMessageFacesContextStringObjectArray() throws Exception
    {
        facesContext.getViewRoot().setLocale(Locale.ENGLISH);
        
        FacesMessage msg = MessageUtils.getMessage(facesContext,
                "javax.faces.component.UIInput.CONVERSION", null);
        assertEquals("Conversion Error", msg.getSummary());

        facesContext.getViewRoot().setLocale(Locale.GERMAN);
        
        msg = MessageUtils.getMessage(facesContext,
                "javax.faces.component.UIInput.CONVERSION", null);
        assertEquals("Konvertierungsfehler", msg.getSummary());
    }

    /**
     * testGetMessageWithBundle
     */
    public void testGetMessageWithBundle() throws Exception
    {
        facesContext.getViewRoot().setLocale(Locale.ENGLISH);
        
        ResourceBundle bundle = ResourceBundle.getBundle(DEFAULT_BUNDLE,
                Locale.ENGLISH);
        FacesMessage msg = MessageUtils.getMessage(bundle,
                "javax.faces.component.UIInput.CONVERSION", null);

        assertEquals("Conversion Error", msg.getSummary());
    }

    /**
     * testGetMessageWithBundleName
     */
    public void testGetMessageWithBundleName() throws Exception
    {
        facesContext.getViewRoot().setLocale(Locale.ENGLISH);
        
        FacesMessage msg = MessageUtils.getMessage(DEFAULT_BUNDLE,
                "javax.faces.component.UIInput.CONVERSION", null);

        assertEquals("Conversion Error", msg.getSummary());
    }

    /**
     * testGetMessageWithBundleNameLocale
     */
    public void testGetMessageWithBundleNameLocale() throws Exception
    {
        FacesMessage msg = MessageUtils.getMessage(DEFAULT_BUNDLE,
                Locale.GERMAN, "javax.faces.component.UIInput.CONVERSION", null);

        assertEquals("Konvertierungsfehler", msg.getSummary());
    }
    
    /**
     * testSubstituteParamsWithDELocale(
     */
    public void testSubstituteParamsWithDELocale() throws Exception {
        String paramString = MessageUtils.substituteParams(Locale.GERMANY, "currency {0,number,currency}", new Object[]{new Double(100)});

        System.out.println(paramString);
        //assertEquals("currency 100,00 ",paramString); // TODO: This fails on 1.4 for some reason.
    }

    /**
     * testSubstituteParamsWithGBLocale(
     */
    public void testSubstituteParamsWithGBLocale() throws Exception {
        String paramString = MessageUtils.substituteParams(Locale.UK, "currency {0,number,currency}", new Object[]{new Double(100)});
        
        System.out.println(paramString);
        assertEquals("currency 100.00",paramString);
    }    
    
    
}
